﻿Type=Class
Version=4.19
ModulesStructureVersion=1
B4J=true
@EndOfDesignText@
'Custom View class - NumericSpinner
'2016 by Robert W.B. Linn, www.rwblinn.de
'Version 20160215
#Region NOTES
'Example using properties and methods
'	...
'	MainForm.Show
'	'Set properties
'	NumericSpinner1.SetMinValue(5)
'	NumericSpinner1.SetMaxValue(10)
'	NumericSpinner1.SetTooltipText($"Use the arrow keys to change the value. Min is ${NumericSpinner1.GetMinValue}, Max is ${NumericSpinner1.GetMaxValue}."$)
'	'Set the initial field value
'	NumericSpinner1.SetFieldValue(9)
'	'To change the customview position after mainform show use callsubdelayed2
'	CallSubDelayed2(NumericSpinner1, "SetWidth", 50)
'	CallSubDelayed2(NumericSpinner1, "SetTop", 80)
'	CallSubDelayed2(NumericSpinner1, "SetLeft", 80)
#End Region

'Custom View Properties: FieldValue as Int, Min and MaxValue as Int, TooltipText as string
#DesignerProperty: Key: FieldValue, Displayname: FieldValue, Fieldtype: Int, Defaultvalue: 0, Description: Use the arrows to increase or decrease the value
#DesignerProperty: Key: MinValue, Displayname: MinValue, Fieldtype: Int, Defaultvalue: 0, Description: Set the minimum value
#DesignerProperty: Key: MaxValue, Displayname: MaxValue, Fieldtype: Int, Defaultvalue: 100, Description: Set the maximum value
#DesignerProperty: Key: TooltipText, Displayname: TooltipText, Fieldtype: String, Defaultvalue: , Description: Use the arrows to increase or decrease the value

Private Sub Class_Globals
	Private Version As String = "v20160215"
	Private fx As JFX
	Private mEventName As String 'ignore
	Private mCallBack As Object 'ignore
	Private mBase As Pane
	Private mProps As Map
	'Views
	Private tfNumericField As TextField
	Private btnUp As ImageView
	Private btnDown As ImageView
End Sub

Public Sub Initialize (vCallback As Object, vEventName As String)
	mEventName = vEventName
	mCallBack = vCallback
End Sub

Public Sub DesignerCreateView (Base As Pane, Lbl As Label, Props As Map)
	mBase = Base
	mProps = Props
	'Set base style
	CSSUtils.SetBorder(mBase, 0, fx.Colors.Transparent, 0)

	'Add the views to the Base pane
	tfNumericField.Initialize("tfNumericField")
	mBase.AddNode(tfNumericField, 0, 0, 0, 0)
	'
	btnUp.Initialize("btnUp")
	btnUp.SetImage(fx.LoadImage(File.DirAssets, "up.png"))
	CSSUtils.SetBorder(btnUp, 3, fx.Colors.Black, 1)
	mBase.AddNode(btnUp, 0, 0, 0, 0)
	'
	btnDown.Initialize("btnDown")
	btnDown.SetImage(fx.LoadImage(File.DirAssets, "down.png"))
	CSSUtils.SetBorder(btnDown, 3, fx.Colors.Black, 1)
	mBase.AddNode(btnDown, 0, 0, 0, 0)
End Sub

'Handle resize of the base - DLTWH
Private Sub Base_Resize (Width As Double, Height As Double)
	tfNumericField.SetLayoutAnimated(0, 1, 0, Width - 26, Height)
	btnUp.SetLayoutAnimated(0, Width - 25, 1, 20, (Height / 2) - 2)
	btnDown.SetLayoutAnimated(0, Width - 25, (Height / 2) + 1, 20, (Height / 2) - 2)
End Sub

Public Sub SetWidth(Width As Double)
	If Width < 100 Then Width = 100
	mBase.PrefWidth = Width
End Sub

Public Sub SetTop(Top As Double)
	If Top < 0 Then Top = 0
	mBase.Top = Top
End Sub

Public Sub SetLeft(Left As Double)
	If Left < 0 Then Left = 0
	mBase.Left = Left
End Sub

Public Sub GetFieldValue As Int
	Return tfNumericField.Text
End Sub

Public Sub SetFieldValue(Value As Int)
	tfNumericField.Text = Value
End Sub

Public Sub SetMinValue(Value As Int)
	If IsNumber(Value) Then mProps.Put("MinValue", Value)
End Sub

Public Sub SetMaxValue(Value As Int)
	If IsNumber(Value) Then mProps.Put("MaxValue", Value)
End Sub

Public Sub GetMinValue As Int
	Return mProps.get("MinValue")
End Sub

Public Sub GetMaxValue As Int
	Return mProps.get("MaxValue")
End Sub

Public Sub SetTooltipText(Value As String)
	tfNumericField.TooltipText = Value
End Sub

Private Sub btnUp_MouseClicked (EventData As MouseEvent)
	If tfNumericField.Text.Length = 0 Then tfNumericField.Text = 0
	SetFieldValue(tfNumericField.Text + 1)
End Sub

Private Sub btnDown_MouseClicked (EventData As MouseEvent)
	If tfNumericField.Text.Length = 0 Then tfNumericField.Text = 0
	SetFieldValue(tfNumericField.Text - 1)
End Sub

'Handle textfield changes:
'If not numeric then set old text; If < min or > max value then set min or max value
Private Sub tfNumericField_TextChanged (Old As String, New As String)
	If Not(IsNumber(New)) And (New.Length > 0) Then tfNumericField.Text = Old
	If tfNumericField.Text < mProps.Get("MinValue") Then tfNumericField.Text = mProps.Get("MinValue") 
	If tfNumericField.Text > mProps.Get("MaxValue") Then tfNumericField.Text = mProps.Get("MaxValue") 
End Sub

Public Sub GetVersion As String
	Return Version
End Sub
